@@ -88,6 +88,8 @@ sub add
     {
         my $hv = Module::Generic::HeaderValue->new_from_header( $this, decode => 1, debug => $self->debug ) ||
             return( $self->error( Module::Generic::HeaderValue->error ) );
+        $self->message( 5, "Got here for string '", overload::StrVal( $this ), "' and header value object '", overload::StrVal( $hv ), "'" );
+        $self->message( 5, "header value is '$hv'" );
         my $ref = {};
         $ref->{name} = $hv->value->first;
         $ref->{value} = $hv->value->second;
@@ -941,6 +943,7 @@ sub load_as_lwp
     $opts->{iv} //= $self->_initialisation_vector->scalar || '';
     my $f = $self->new_file( $file );
     my $host = $opts->{host} || $self->host || '';
+    # $self->message( 4, "Loading LWP cookies from file '$f' for host '$host'" );
     $f->open( '<', { binmode => ( $opts->{decrypt} ? 'raw' : 'utf-8' ) }) || return( $self->pass_error( $f->error ) );
     my $code = sub
     {
@@ -2244,7 +2247,7 @@ For example:
 
 See also L<modperl testing documentation|https://perl.apache.org/docs/general/testing/testing.html>
 
-But, if for some reason, you do not want to perform the mod_perl tests, you can call use C<NO_MOD_PERL=1> when calling C<perl Makefile.PL>, such as:
+But, if for some reason, you do not want to perform the mod_perl tests, you can use C<NO_MOD_PERL=1> when calling C<perl Makefile.PL>, such as:
 
     NO_MOD_PERL=1 perl Makefile.PL
     make
